@@ -8,10 +8,10 @@ class VirtualCircuit(models.Model):
 
     vcid = models.PositiveSmallIntegerField(
         primary_key=True,
-        verbose_name='ID'
+        verbose_name='ID',
     )
     name = models.CharField(
-        max_length=64
+        max_length=64,
     )
     status = models.CharField(
         max_length=30,
@@ -20,15 +20,16 @@ class VirtualCircuit(models.Model):
     )
     context = models.CharField(
         max_length=100,
-        blank=True
+        blank=True,
     )
 
     class Meta:
         ordering = ['vcid']
+        verbose_name = 'Virtual Circuit'
+        verbose_name_plural = 'Virtual Circuits'
 
     def __str__(self):
-        return self.name
-
+        return f'{self.vcid} ({self.name})'
 
 class VirtualCircuitVLAN(models.Model):
     """Virtual Circuit to VLAN relationship."""
@@ -36,13 +37,17 @@ class VirtualCircuitVLAN(models.Model):
     virtual_circuit = models.ForeignKey(
         to=VirtualCircuit,
         on_delete=models.CASCADE,
-        related_name='vlans'
+        related_name='vlans',
+        verbose_name='Virtual Circuit',
     )
     vlan = models.OneToOneField(
         to=VLAN,
         on_delete=models.CASCADE,
-        related_name='vlan_of'
+        related_name='vlan_of',
+        verbose_name='VLAN',
     )
 
     class Meta:
         ordering = ['virtual_circuit']
+        verbose_name = 'Virtual-Circuit-to-VLAN connection'
+        verbose_name_plural = 'Virtual-Circuit-to-VLAN connections'
