@@ -4,24 +4,29 @@ from utilities.choices import ButtonColorChoices
 
 menu_items = (
     PluginMenuItem(
-        link='plugins:netbox_virtual_circuit_plugin:list_virtual_circuits',
+        link='plugins:netbox_virtual_circuit_plugin:virtual_circuit_list',
         link_text='Virtual Circuits',
-        permissions=[],
+        permissions=['netbox_virtual_circuit_plugin.view_virtualcircuit'],
         buttons=(
-            # Link to the admin view to add a virtual circuit if user has "add_virtualcircuit" permission.
             PluginMenuButton(
-                link='admin:netbox_virtual_circuit_plugin_virtualcircuit_add',
+                link='plugins:netbox_virtual_circuit_plugin:virtual_circuit_add',
                 title='Add a new virtual circuit',
                 icon_class='fa fa-plus',
                 color=ButtonColorChoices.GREEN,
                 permissions=['netbox_virtual_circuit_plugin.add_virtualcircuit']
             ),
-            # Links to the admin view to assign a virtual circuit to a VLAN if user has the "add_virtualcircuitvlan" permission.
+        )
+    ),
+    PluginMenuItem(
+        link='plugins:netbox_virtual_circuit_plugin:virtual_circuit_vlan_list',
+        link_text='Connections',
+        permissions=['netbox_virtual_circuit_plugin.view_virtualcircuitvlan'],
+        buttons=(
             PluginMenuButton(
-                link='admin:netbox_virtual_circuit_plugin_virtualcircuitvlan_add',
-                title='Assign a virtual circuit to a VLAN',
+                link='plugins:netbox_virtual_circuit_plugin:virtual_circuit_vlan_add',
+                title='Assign a VLAN to a Virtual Circuit',
                 icon_class='fa fa-plus',
-                color=ButtonColorChoices.BLUE,
+                color=ButtonColorChoices.GREEN,
                 permissions=['netbox_virtual_circuit_plugin.add_virtualcircuitvlan']
             ),
         )
